from .base import BaseCFObject


class Metadata(BaseCFObject):
    top_level_key = "Metadata"
